@@ -3,7 +3,7 @@ let mod, instance;
 WebAssembly.instantiateStreaming(fetch("main.wasm"), go.importObject).then((result) => {
     mod = result.module;
     instance = result.instance;
-    document.getElementById("gtree").disabled = false;
+    // document.getElementById("gtree").disabled = false;
 
     console.clear();
     go.run(instance);
@@ -17,6 +17,9 @@ const clearMarkdown = () => {
 const generateTree = () => {
   gtree();
 };
+window.onload = function () {
+  generateTree();
+};
 
 const copyToClipboard = () => {
   const tree = document.getElementById("treeView");
@@ -33,3 +36,13 @@ const resetParts = () => {
   document.getElementById("parts3").value = "──";
   document.getElementById("parts4").value = "│";
 };
+
+const reset = () => {
+  resetParts();
+  generateTree();
+};
+
+const clearTxt = () => {
+  clearMarkdown();
+  document.getElementById("treeView").remove();
+};
