@@ -7,5 +7,5 @@ import (
 )
 
 func verify(in io.Reader, options []gtree.Option) error {
-	return gtree.Verify(in, options...)
+	return gtree.VerifyFromMarkdown(in, options...)
 }
